import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.UIManager;

import SwingInterop.Form1;
import SwingInterop.Form2;
import com.jnbridge.jnbcore.DotNetSide;

/**
 * Here is a sample SWING app that uses the WindowsForms proxy to communicate with the engine
 * in order to display Windows Forms as part of a SWING app.
 * 
 * @author sguest (modifications by Wayne Citrin)
 *
 */
public class MainForm extends JFrame 
{
	// Some SWING controls
	private javax.swing.JMenuBar jJMenuBar = null;
	private javax.swing.JPanel jPanel = null;
	private javax.swing.JLabel jLabel = null;
	private javax.swing.JPanel jContentPane = null;
	private javax.swing.JButton jButton = null;
	private javax.swing.JTextField jTextField = null;
		
	private javax.swing.JButton jButton1 = null;
	public static void main(String[] args) 
	{
		// JNBRIDGE STUFF
		// initialize the Java-side client
		DotNetSide.init(args[0]);

		MainForm mf = new MainForm();
		mf.show();
	}

	public MainForm() 
	{		
		// Initialize the SWING controls
		super();				
		initialize();
	}

	/**
	 * Initializer for the SWING form
	 *
	 */
	private void initialize() 
	{
		// Set the look and feel so that this window is like the others that are opened through
		// Windows Forms
		try
		{
			UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
		}
		catch (Exception ulnfe)
		{
			// Ignored - we probably are not running on a non-windows box
		}
		
		this.setJMenuBar(getJJMenuBar());
		this.setContentPane(getJContentPane());
		this.setSize(512, 148);
		this.setTitle("A SWING Form calling Windows Forms");
		
		this.addWindowListener(new java.awt.event.WindowAdapter() { 
			public void windowClosing(java.awt.event.WindowEvent e) {    
				System.out.println("Window is closing...");
				System.exit(0);
			}
		});
	}


	private javax.swing.JMenuBar getJJMenuBar() {
		if(jJMenuBar == null) {
			jJMenuBar = new javax.swing.JMenuBar();
		}
		return jJMenuBar;
	}

	private javax.swing.JLabel getJLabel() {
		if(jLabel == null) {
			jLabel = new javax.swing.JLabel();
			jLabel.setBounds(18, 18, 115, 15);
			jLabel.setText("Type in a message:");
			jLabel.setName("jLabel");
		}
		return jLabel;
	}

	private javax.swing.JPanel getJContentPane() {
		if(jContentPane == null) {
			jContentPane = new javax.swing.JPanel();
			jContentPane.setLayout(null);
			jContentPane.add(getJLabel(), null);
			jContentPane.add(getJButton(), null);
			jContentPane.add(getJTextField(), null);
			jContentPane.add(getJButton1(), null);
		}
		return jContentPane;
	}

	private javax.swing.JButton getJButton() {
		if(jButton == null) {
			jButton = new javax.swing.JButton();
			jButton.setBounds(272, 63, 101, 32);
			jButton.setText("Open Form1");
			jButton.addActionListener(new java.awt.event.ActionListener() { 
				public void actionPerformed(java.awt.event.ActionEvent e) {
					    				
					try
					{
						// JNBRIDGE STUFF
						// Open the form in modal mode
						Form1 form1 = new Form1();
						form1.Set_Message(jTextField.getText());
						// register the listener
						MessageWindowListener mwl = new MessageWindowListener(jTextField);
						form1.add_ButtonClicked(mwl);
						form1.ShowDialog();
						String result = form1.Get_Message();
						form1.dotNetDispose();
					}
					catch (Exception e2)
					{
						System.out.println(e2.toString());
						e2.printStackTrace();
					}
				}
			});
		}
		return jButton;
	}

	private javax.swing.JTextField getJTextField() {
		if(jTextField == null) {
			jTextField = new javax.swing.JTextField();
			jTextField.setBounds(163, 18, 320, 19);
		}
		return jTextField;
	}

	private javax.swing.JButton getJButton1() {
		if(jButton1 == null) {
			jButton1 = new javax.swing.JButton();
			jButton1.setBounds(376, 63, 101, 32);
			jButton1.setText("Open Form2");
			jButton1.addActionListener(new java.awt.event.ActionListener() { 
				public void actionPerformed(java.awt.event.ActionEvent e) 
				{    
					try
					{
						// JNBRIDGE STUFF
						// Open the second form, but not in modal mode
						Form2.showNonModal();
					}
					catch (Exception e2)
					{
						System.out.println(e2.getMessage());
					}
				}
			});
		}
		return jButton1;
	}
}  
